#include <Servo.h>

Servo steeringServo;

int servoPin = 6;
int motorPinE1 = 9;
int motorPinE2 = 11;

int arm1UpPin = 3;
int arm1DownPin = 5;
int arm2UpPin = 7;
int arm2DownPin = 8;
int arm3UpPin = A0;
int arm3DownPin = 13;
int arm4UpPin = 2;
int arm4DownPin = 4;
int arm5LeftPin = 10;
int arm5RightPin = 12;

int armLightPin = A1;

int servoDegree = 90;
int driveSpeed = 9;
boolean armLightOn = false;

char received = ' ';
String receivedVoice = "";
boolean voiceControlOn = false;

void setup() {
  Serial.begin(9600);
  steeringServo.attach(servoPin);
  servoDegree = steeringServo.read();

  pinMode(motorPinE1, OUTPUT);
  pinMode(motorPinE2, OUTPUT);

  pinMode(arm1UpPin, OUTPUT);
  pinMode(arm1DownPin, OUTPUT);

  pinMode(arm2UpPin, OUTPUT);
  pinMode(arm2DownPin, OUTPUT);

  pinMode(arm3UpPin, OUTPUT);
  pinMode(arm3DownPin, OUTPUT);

  pinMode(arm4UpPin, OUTPUT);
  pinMode(arm4DownPin, OUTPUT);

  pinMode(arm5LeftPin, OUTPUT);
  pinMode(arm5RightPin, OUTPUT);

  pinMode(armLightPin, OUTPUT);
}

void loop() {
  if(Serial.available() > 0){

    if(!voiceControlOn){
      received = Serial.read();
    }else{
      receivedVoice = Serial.readString();
      //receivedVoice = receivedVoice.toLowerCase();
    }
    
    Serial.print(received);    Serial.print("-");    Serial.println(receivedVoice);

    if(isDigit(received)){
      driveSpeed = (int) received - 48;
    }
    //receivedVoice.toLowerCase();
    
    if(received == 'o'){
      armLightOn = true;
    }else if(received == 'p'){
      armLightOn = false;
    }

    if(received == 'u' || receivedVoice == "u"){
      voiceControlOn = true;
      received = ' ';
      receivedVoice = "";
    }else if(received == 'v' || receivedVoice == "v"){
      voiceControlOn = false;
      received = ' ';
      receivedVoice = "";
    }
    
  }

  if(armLightOn){
    digitalWrite(armLightPin, HIGH);
  }else{
    digitalWrite(armLightPin, LOW);
  }
  
  if(received == 'a' || receivedVoice == "left"){
    steeringServo.write(--servoDegree);
    delay(50);
    
  }else if(received == 'd' || receivedVoice == "right"){
    steeringServo.write(++servoDegree);
    delay(50);
    
  }else if(received == 'x' || receivedVoice == "stop steering"){
    steeringServo.write(servoDegree);
    
  }else if(received == 'w' || receivedVoice == "forward"){
    analogWrite(motorPinE2, driveSpeed*28);
    digitalWrite(motorPinE1, LOW);
    
  }else if(received == 's' || receivedVoice == "reverse"){
    digitalWrite(motorPinE1, HIGH);
    digitalWrite(motorPinE2, LOW);
    
  }else if(received == 'y' || receivedVoice == "stop moving"){
    digitalWrite(motorPinE2, LOW);
    digitalWrite(motorPinE1, LOW);
    
  }else if(received == 'e' || receivedVoice == "1 up" || receivedVoice == "shoulder up"){
    digitalWrite(arm1UpPin, HIGH);
    digitalWrite(arm1DownPin, LOW);
    
  }else if(received == 'f' || receivedVoice == "1 down" || receivedVoice == "shoulder down"){
    digitalWrite(arm1UpPin, LOW);
    digitalWrite(arm1DownPin, HIGH);
    
  }else if(received == 'g' || receivedVoice == "2 up" || receivedVoice == "elbow up"){
    digitalWrite(arm2UpPin, HIGH);
    digitalWrite(arm2DownPin, LOW);
    
  }else if(received == 'h' || receivedVoice == "2 down" || receivedVoice == "elbow down"){
    digitalWrite(arm2UpPin, LOW);
    digitalWrite(arm2DownPin, HIGH);
    
  }else if(received == 'i' || receivedVoice == "3 up"){
    digitalWrite(arm3UpPin, HIGH);
    digitalWrite(arm3DownPin, LOW);
    
  }else if(received == 'j' || receivedVoice == "3 down"){
    digitalWrite(arm3UpPin, LOW);
    digitalWrite(arm3DownPin, HIGH);
    
  }else if(received == 'k' || receivedVoice == "4 up" || receivedVoice == "drop"){
    digitalWrite(arm4UpPin, HIGH);
    digitalWrite(arm4DownPin, LOW);
    
  }else if(received == 'l' || receivedVoice == "4 down" || receivedVoice == "pick"){
    digitalWrite(arm4UpPin, LOW);
    digitalWrite(arm4DownPin, HIGH);
    
  }else if(received == 'm' || receivedVoice == "5 left" || receivedVoice == "base left"){
    digitalWrite(arm5LeftPin, HIGH);
    digitalWrite(arm5RightPin, LOW);
    
  }else if(received == 'n' || receivedVoice == "5 right" || receivedVoice == "base right"){
    digitalWrite(arm5LeftPin, LOW);
    digitalWrite(arm5RightPin, HIGH);
    
  }else if(received == 'b' || receivedVoice == "1 stop" || receivedVoice == "3 stop"){
    digitalWrite(arm1UpPin, LOW);
    digitalWrite(arm1DownPin, LOW);
    digitalWrite(arm3UpPin, LOW);
    digitalWrite(arm3DownPin, LOW);
    
  }else if(received == 'c' || receivedVoice == "2 stop" || receivedVoice == "4 stop"){
    digitalWrite(arm2UpPin, LOW);
    digitalWrite(arm2DownPin, LOW);
    digitalWrite(arm4UpPin, LOW);
    digitalWrite(arm4DownPin, LOW);
    
  }else if(received == 'z' || receivedVoice == "5 stop"){
    digitalWrite(arm5LeftPin, LOW);
    digitalWrite(arm5RightPin, LOW);
    
  }else if(received == 't' || receivedVoice == "stop all"){
    digitalWrite(motorPinE2, LOW);
    digitalWrite(motorPinE1, LOW);
    
    digitalWrite(arm1UpPin, LOW);
    digitalWrite(arm1DownPin, LOW);
    
    digitalWrite(arm2UpPin, LOW);
    digitalWrite(arm2DownPin, LOW);
    
    digitalWrite(arm3UpPin, LOW);
    digitalWrite(arm3DownPin, LOW);
    
    digitalWrite(arm4UpPin, LOW);
    digitalWrite(arm4DownPin, LOW);
    
    digitalWrite(arm5LeftPin, LOW);
    digitalWrite(arm5RightPin, LOW);
    
    servoDegree = 90;
    steeringServo.write(servoDegree);
    
  }

}
